package main

import (
	"context"
	"fmt"
	"time"

	"github.com/sirupsen/logrus"
	"gitlab.atsaero.ru/go-packages/atsami/ami"
)

const (
	user   = "ami_user"
	secret = "ami_user"
	addr   = "192.168.68.51:5038"
)

func main() {
	logger := logrus.New().WithField("module", "test")

	// Формируем контейнер соединений, указываем аутентификационные данные и количество воркеров в каждом подпуле.
	// Подпулы инициализируются при получении первой команды сессии
	pool := ami.NewConnPool(context.Background(), user, secret, 3, logger)

	//сессия определяется адресом астериска
	session, err := ami.NewSession(context.Background(), pool, addr, logger)
	if err != nil {
		logger.Fatal(err)
	}

	for i := 0; i < 10; i++ {
		uuid := fmt.Sprintf("originate_%d", i)

		// отложенные функции для обработки очереди событий астериска
		// не все команды требуют передачи отложенных функций
		cbBegin := func(e ami.EventResponse) error {
			if e.Event() == ami.EventDialBegin {
				logger.Infof("start call %s", e.Key())
			}
			return nil
		}

		cbHangup := func(e ami.EventResponse) error {
			if e.Event() == ami.EventHangup {
				logger.Infof("hungup call %s", e.Key())
			}
			return nil
		}

		// отправляем команду в очередь воркеров. В данный момент емкость очереди - 1000 команд
		err := session.Originate(uuid, "SIP/ast068036/89085127846", "test", "autodialer-ivr-robot", "_ACC=2", 70000, cbBegin, cbHangup)
		if err != nil {
			logger.Errorf("originate %s failed: %v", uuid, err)
		} else {
			logger.Infof("call %s sent to queue successfully", uuid)
		}

		time.Sleep(time.Millisecond * 100)
	}

	// воркеры обрабатывают очередь асинхронно. Управление состоянием осуществляется через вызовы отложенных функций, поэтому здесь необходима блокировка.
	select {}
}
